Enumeration
ArrowListSliceReturnFixedSizeList
since: 23.0.0
Description [src]
They correspond to the values of
std::optional<bool> for arrow::compute::ListSliceOptions::return_fixed_size_list.
Available since: 23.0.0
Members
-
GARROW_LIST_SLICE_RETURN_FIXED_SIZE_LIST_AUTO -
Return the same type which was passed in (default).
- Value:
0 - Available since: 23.0.0
- Value:
-
GARROW_LIST_SLICE_RETURN_FIXED_SIZE_LIST_FALSE -
Explicitly return the same type which was passed in.
- Value:
1 - Available since: 23.0.0
- Value:
-
GARROW_LIST_SLICE_RETURN_FIXED_SIZE_LIST_TRUE -
Return a FixedSizeListArray. If stop is after a list element’s length, nulls will be appended to create the requested slice size.
- Value:
2 - Available since: 23.0.0
- Value: